@@ -2,50 +2,66 @@
 #'
 #' Adds axes to the internal region of an OSM plot.
 #'
-#' @param map A ggplot2 object to which the axes are to be added
+#' @param map A \code{ggplot2} object to which the axes are to be added.
 #' @param colour Colour of axis (determines colour of all elements: lines,
-#' ticks, and labels)
-#' @param pos Positions of axes and labels relative to entire plot device
+#' ticks, and labels).
+#' @param pos Positions of axes and labels relative to entire plot device.
 #' @param alpha alpha value for semi-transparent background surrounding axes and
-#' labels (lower values increase transparency)
-#' @param fontsize Size of axis font 
-#' @param fontface Fontface for axis labels (1:4=plain,bold,italic,bold-italic)
-#' @param fontfamily Family of axis font (for example, 'Times')
-#' @return Modified version of map with axes added
+#' labels (lower values increase transparency).
+#' @param fontsize Size of axis font (in \code{ggplot2} terms; default=3).
+#' @param fontface Fontface for axis labels (1:4=plain,bold,italic,bold-italic).
+#' @param fontfamily Family of axis font (for example, `\code{Times}').
+#' @param ... Mechanism to allow many parameters to be passed with alternative
+#' names (\code{color} for \code{colour} and \code{xyz} for \code{fontxyz}.
+#' @return Modified version of \code{map} with axes added.
 #' @export
 #'
-#' @seealso \code{\link{plot_osm_basemap}}.
+#' @seealso \code{\link{osm_basemap}}.
 #'
 #' @examples
 #' bbox <- get_bbox (c (-0.13, 51.5, -0.11, 51.52))
-#' map <- plot_osm_basemap (bbox=bbox, bg="gray20")
+#' map <- osm_basemap (bbox=bbox, bg="gray20")
 #' map <- add_osm_objects (map, london$dat_BNR, col="gray40") 
 #' map <- add_axes (map)
 #' print (map)
 #'
 #' # Map items are added sequentially, so adding axes prior to objects will
 #' # produce a different result.
-#' map <- plot_osm_basemap (bbox=bbox, bg="gray20")
+#' map <- osm_basemap (bbox=bbox, bg="gray20")
 #' map <- add_axes (map)
 #' map <- add_osm_objects (map, london$dat_BNR, col="gray40") 
-#' print (map)
+#' print_osm_map (map)
 
 add_axes <- function (map, colour="black", pos=c(0.02,0.03),
-                      alpha=0.4, fontsize=3, fontface, fontfamily)
+                      alpha=0.4, fontsize=3, fontface, fontfamily, ...)
 {
+    args <- list (...)
+    if (hasArg ("color")) colour <- args [['color']]
+    if (hasArg ("position")) pos <- args [['position']]
+    if (hasArg ("size")) fontsize <- args [['size']]
+    if (hasArg ("face")) fontface <- args [['face']]
+    if (hasArg ("family")) fontfamily <- args [['family']]
+
     # ---------------  sanity checks and warnings  ---------------
     # ---------- map
     if (missing (map)) stop ('map must be supplied to add_axes')
-    if (!is (map, 'ggplot')) stop ('map must be a ggplot object')
-
-    # ---------- alpha
-    alpha <- test_len1 (alpha, 'alpha')
-    alpha <- test_numeric (alpha, 'alpha', 0.4)
-    alpha <- test_range (alpha, 'alpha', c (0, 1), 0.4)
+    if (!is (map, 'ggplot')) stop ('map must be a ggplot2 object')
+    # ---------- colour
+    junk <- tryCatch (
+                      col2rgb (colour),
+                      error = function (e) 
+                      {
+                          e$message <-  paste0 ("Invalid colour: ", colour)
+                          stop (e)
+                      })
     # ---------- pos
     pos <- test_len2 (pos, 'pos')
     pos <- test_numeric (pos, 'pos', c (0.02, 0.03))
     pos <- test_range (pos, 'pos', c (0, 1), c (0.02, 0.03))
+    # ---------- alpha
+    alpha <- test_len1 (alpha, 'alpha')
+    alpha <- test_numeric (alpha, 'alpha', 0.4)
+    alpha <- test_range (alpha, 'alpha', c (0, 1), 0.4)
     # ---------- fontsize
     fontsize <- test_len1 (fontsize, 'fontsize')
     fontsize <- test_numeric (fontsize, 'fontsize', 3)
